@@ -2,10 +2,13 @@
 
 import os
 
-DEFAULT_CONFIG_DIR = f"{os.path.expanduser('~')}/.config/voiceassistant"
+USER_PATH = os.path.expanduser("~")
 PROJECT_PATH = os.path.dirname(os.path.realpath(__file__))
+
+DEFAULT_CONFIG_DIR = f"{USER_PATH}/.config/voiceassistant"
+CACHE_DIR = f"{USER_PATH}/.cache/voiceassistant/"
 DATA_DIR = f"{PROJECT_PATH}/data"
-CACHE_DIR = f"{PROJECT_PATH}/../../.vass_cache"
+
 
 # must be set in order to construct google.cloud.speech.SpeechClient
 if "GOOGLE_APPLICATION_CREDENTIALS" not in os.environ:
